/*
 * $Header: /home/cvspublic/jakarta-slide/src/share/org/apache/slide/store/IndexStore.java,v 1.5.2.1 2004/02/05 16:05:12 mholz Exp $
 * $Revision: 1.5.2.1 $
 * $Date: 2004/02/05 16:05:12 $
 *
 * ====================================================================
 *
 * Copyright 1999-2002 The Apache Software Foundation 
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */ 

package org.apache.slide.store;

import org.apache.slide.common.Service;
import org.apache.slide.common.ServiceAccessException;
import org.apache.slide.common.SlideToken;
import org.apache.slide.common.Uri;
import org.apache.slide.content.NodeRevisionContent;
import org.apache.slide.content.NodeRevisionDescriptor;
import org.apache.slide.search.SearchLanguage;
import org.apache.slide.search.SearchQuery;
import org.apache.slide.search.SearchQueryResult;

/**
 * Store for Index.
 * 
 * @author <a href="mailto:remm@apache.org">Remy Maucherat</a>
 * @version $Revision: 1.5.2.1 $
 */
public interface IndexStore extends Service {
    
    
    // ------------------------------------------------------ Interface Methods
    
    
    /**
     * Index an object content.
     * 
     * @param uri Uri
     * @exception ServiceAccessException Error accessing the Data Source
     */
    void index(Uri uri, NodeRevisionDescriptor revisionDescriptor,
               NodeRevisionContent revisionContent)
        throws ServiceAccessException;
    
    
    /**
     * Drop an object revision from the index.
     * 
     * @param uri Uri
     * @exception ServiceAccessException Error accessing the Data Source
     */
    void drop(Uri uri, NodeRevisionDescriptor revisionDescriptor)
        throws ServiceAccessException;
    
    
    /**
     * Search.
     * 
     * @exception ServiceAccessException Error accessing the Data Source
     */
    SearchQueryResult search(SlideToken token, SearchQuery query)
        throws ServiceAccessException;
    
    
    /**
     * Get supported laguages list.
     */
    SearchLanguage[] getSupportedLanguages();
    
    
}
