/*
 * $Header: /home/cvspublic/jakarta-slide/src/share/org/apache/slide/util/logger/StoreLogger.java,v 1.1.2.1 2004/02/05 16:05:15 mholz Exp $
 * $Revision: 1.1.2.1 $
 * $Date: 2004/02/05 16:05:15 $
 *
 * ====================================================================
 *
 * Copyright 1999-2002 The Apache Software Foundation 
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.apache.slide.util.logger;


/**
 * Logger used by store. Abstracting from limited slide logging in hope of a better future.
 *   
 * @author <a href="mailto:ozeigermann@c1-fse.de">Oliver Zeigermann</a>
 */
public class StoreLogger {

    protected Logger logger;
    protected String logChannel;

    // ctor for subclasses not working on slide logger
    public StoreLogger() {
    }

    public StoreLogger(Logger logger, String logChannel) {
        this.logger = logger;
        this.logChannel = logChannel;
    }

    public StoreLogger cloneWithNewLogChannel(String logChannel) {
        return new StoreLogger(logger, logChannel);
    }

    public String getLogChannel() {
        return logChannel;
    }

    public void log(String message, int level) {
        if (logger != null) {
            logger.log(message, logChannel, level);
        }
    }

    public void log(String message, int level, Throwable t) {
        if (logger != null) {
            logger.log(message, logChannel, level);
            if (t != null) {
                logger.log(t, logChannel, level);
            }
        }
    }

    public void logInfo(String message) {
        log(message, Logger.INFO);
    }

    public void logFine(String message) {
        log(message, Logger.DEBUG);
    }

    public void logFiner(String message) {
        log(message, Logger.DEBUG);
    }

    public void logFinest(String message) {
        log(message, Logger.DEBUG);
    }

    public void logWarning(String message) {
        log(message, Logger.WARNING);
    }

    public void logWarning(String message, Throwable t) {
        log(message, Logger.WARNING, t);
    }

    public void logSevere(String message) {
        log(message, Logger.EMERGENCY);
    }

    public void logSevere(String message, Throwable t) {
        log(message, Logger.EMERGENCY, t);
    }

}
