/*
 * $Header: /home/cvspublic/jakarta-slide/src/stores/org/apache/slide/store/txfile/rm/StreamableResourceManager.java,v 1.2.2.1 2004/02/05 16:07:53 mholz Exp $
 * $Revision: 1.2.2.1 $
 * $Date: 2004/02/05 16:07:53 $
 *
 * ====================================================================
 *
 * Copyright 1999-2002 The Apache Software Foundation 
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.apache.slide.store.txfile.rm;

import java.io.InputStream;
import java.io.OutputStream;

/**
 * A resource manager for streamable resources.
 * 
 * @author <a href="mailto:ozeigermann@c1-fse.de">Oliver Zeigermann</a>
 *
 */
public interface StreamableResourceManager extends ResourceManager {

    /**
     * Opens a streamable resource for reading.
     * 
     * <br><br>
     * <em>Important</em>: By contract, the application is responsible for closing the stream after its work is finished.
     * 
     * @param txId identifier for the transaction in which the streamable resource is to be openend
     * @param resourceId identifier for the streamable resource to be opened
     * @return stream to read from 
     * @throws ResourceManagerException if the resource does not exist or any other error occured
     */
    public InputStream readResource(Object txId, Object resourceId) throws ResourceManagerException;
    
    /**
     * Opens a streamable resource for a single reading request not inside the scope of a transaction.
     *  
     * <br><br>
     * <em>Important</em>: By contract, the application is responsible for closing the stream after its work is finished.
     * 
     * @param resourceId identifier for the streamable resource to be opened
     * @return stream to read from 
     * @throws ResourceManagerException if the resource does not exist or any other error occured
     */
    public InputStream readResource(Object resourceId) throws ResourceManagerException;

    /**
     * Opens a resource for writing. 
     * 
     * <br><br>
     * <em>Important</em>: By contract, the application is responsible for closing the stream after its work is finished.
     * 
     * @param txId identifier for the transaction in which the streamable resource is to be openend
     * @param resourceId identifier for the streamable resource to be opened
     * @return stream to write to 
     * @throws ResourceManagerException if the resource does not exist or any other error occured
     */
    public OutputStream writeResource(Object txId, Object resourceId) throws ResourceManagerException;

}
